pub struct PrefetchEngine { /* private fields */ }Expand description
Prefetch engine that generates frame requests based on playhead movement.
Implementations
Sourceimpl PrefetchEngine
impl PrefetchEngine
Sourcepub fn new(config: PrefetchConfig, max_position: i64) -> Self
pub fn new(config: PrefetchConfig, max_position: i64) -> Self
Create a new prefetch engine.
Sourcepub fn update(&mut self, new_position: i64) -> Vec<PrefetchRequest>
pub fn update(&mut self, new_position: i64) -> Vec<PrefetchRequest>
Update the playhead position and get new prefetch requests.
Call this every time the playhead moves. Returns a list of positions to prefetch, sorted by priority (most urgent first).
Sourcepub fn mark_cached(&mut self, position: i64)
pub fn mark_cached(&mut self, position: i64)
Mark a position as cached (already decoded).
Sourcepub fn invalidate(&mut self, position: i64)
pub fn invalidate(&mut self, position: i64)
Invalidate a cached position.
Sourcepub fn invalidate_all(&mut self)
pub fn invalidate_all(&mut self)
Invalidate all cached positions.
Sourcepub fn direction(&self) -> PlayDirection
pub fn direction(&self) -> PlayDirection
Get the current detected play direction.
Sourcepub fn cached_count(&self) -> usize
pub fn cached_count(&self) -> usize
Get count of cached/pending positions.