pub struct DirtyRegion {
pub start_frame: u64,
pub end_frame: u64,
}Expand description
A contiguous range of frames that require re-rendering.
Fields
start_frame: u64First dirty frame (inclusive).
end_frame: u64Last dirty frame (exclusive).
Implementations
Sourceimpl DirtyRegion
impl DirtyRegion
Sourcepub fn new(start_frame: u64, end_frame: u64) -> Self
pub fn new(start_frame: u64, end_frame: u64) -> Self
Create a new dirty region.
If end_frame <= start_frame the region is normalised to a single-frame
region [start_frame, start_frame + 1).
Sourcepub fn overlaps(&self, other: &DirtyRegion) -> bool
pub fn overlaps(&self, other: &DirtyRegion) -> bool
Returns true when the two regions overlap or are adjacent.
Sourcepub fn merge(&self, other: &DirtyRegion) -> DirtyRegion
pub fn merge(&self, other: &DirtyRegion) -> DirtyRegion
Merge two regions into a bounding region covering both.
Sourcepub fn frame_count(&self) -> u64
pub fn frame_count(&self) -> u64
Number of frames covered by this region.