pub enum InsertMode {
Overwrite,
Ripple,
PushPull,
}Expand description
How a clip insertion interacts with existing timeline content.
Variants
Overwrite
Overwrites existing content at the target position.
Ripple
Pushes all subsequent clips downstream to make room.
PushPull
Pulls downstream clips and fills gaps with handles.
Implementations
Sourceimpl InsertMode
impl InsertMode
Sourcepub fn description(&self) -> &'static str
pub fn description(&self) -> &'static str
Short description of the insert mode.
Sourcepub fn shifts_clips(&self) -> bool
pub fn shifts_clips(&self) -> bool
Returns true if this mode shifts existing clips in time.