pub struct MarkerEditor { /* private fields */ }Expand description
Manages a collection of editable markers on a timeline.
Implementations
Sourceimpl MarkerEditor
impl MarkerEditor
Sourcepub fn add_point(&mut self, position: u64, label: impl Into<String>) -> u64
pub fn add_point(&mut self, position: u64, label: impl Into<String>) -> u64
Add a point marker and return its ID.
Sourcepub fn add_range(
&mut self,
start: u64,
end: u64,
label: impl Into<String>,
) -> u64
pub fn add_range( &mut self, start: u64, end: u64, label: impl Into<String>, ) -> u64
Add a range marker and return its ID.
Sourcepub fn remove(&mut self, id: u64) -> Option<EditMarker>
pub fn remove(&mut self, id: u64) -> Option<EditMarker>
Remove a marker by ID.
Sourcepub fn get(&self, id: u64) -> Option<&EditMarker>
pub fn get(&self, id: u64) -> Option<&EditMarker>
Get a marker by ID.
Sourcepub fn get_mut(&mut self, id: u64) -> Option<&mut EditMarker>
pub fn get_mut(&mut self, id: u64) -> Option<&mut EditMarker>
Get a mutable reference to a marker by ID.
Sourcepub fn sorted(&self) -> Vec<&EditMarker>
pub fn sorted(&self) -> Vec<&EditMarker>
Return all markers sorted by position.
Sourcepub fn filter_by_category(&self, cat: MarkerCategory) -> Vec<&EditMarker>
pub fn filter_by_category(&self, cat: MarkerCategory) -> Vec<&EditMarker>
Filter markers by category.
Sourcepub fn delete_by_category(&mut self, cat: MarkerCategory) -> usize
pub fn delete_by_category(&mut self, cat: MarkerCategory) -> usize
Delete all markers that match a given category.
Sourcepub fn markers_at(&self, pos: u64) -> Vec<&EditMarker>
pub fn markers_at(&self, pos: u64) -> Vec<&EditMarker>
Find all markers whose range contains the given position.