pub struct RenderChunk {
pub chunk_id: usize,
pub frame_start: u64,
pub frame_end: u64,
pub output_path: Option<PathBuf>,
}Expand description
A contiguous range of frames assigned to one render worker.
Fields
chunk_id: usizeZero-based chunk index.
frame_start: u64First frame of the chunk (inclusive).
frame_end: u64Last frame of the chunk (exclusive).
output_path: Option<PathBuf>Optional path for writing the chunk output.
Implementations
Sourceimpl RenderChunk
impl RenderChunk
Sourcepub fn new(chunk_id: usize, frame_start: u64, frame_end: u64) -> Self
pub fn new(chunk_id: usize, frame_start: u64, frame_end: u64) -> Self
Create a new render chunk without an output path.
Sourcepub fn with_output(
chunk_id: usize,
frame_start: u64,
frame_end: u64,
output_path: PathBuf,
) -> Self
pub fn with_output( chunk_id: usize, frame_start: u64, frame_end: u64, output_path: PathBuf, ) -> Self
Create a render chunk with an explicit output path.
Sourcepub fn frame_count(&self) -> u64
pub fn frame_count(&self) -> u64
Number of frames in this chunk.