pub struct TransitionRenderer;Expand description
Transition renderer helper.
Implementations
Sourceimpl TransitionRenderer
impl TransitionRenderer
Sourcepub fn blend_video(
frame_a: &VideoFrame,
frame_b: &VideoFrame,
transition: &Transition,
progress: f64,
) -> VideoFrame
pub fn blend_video( frame_a: &VideoFrame, frame_b: &VideoFrame, transition: &Transition, progress: f64, ) -> VideoFrame
Blend two video frames based on transition progress.
progress ranges from 0.0 (fully frame_a) to 1.0 (fully frame_b).
When the two frames have different dimensions the larger frame is returned
unchanged. When formats differ frame_a is returned unchanged.
Sourcepub fn mix_audio(
frame_a: &AudioFrame,
frame_b: &AudioFrame,
_transition: &Transition,
progress: f64,
) -> AudioFrame
pub fn mix_audio( frame_a: &AudioFrame, frame_b: &AudioFrame, _transition: &Transition, progress: f64, ) -> AudioFrame
Mix two audio frames based on transition progress (cross-fade).
progress ranges from 0.0 (fully frame_a) to 1.0 (fully frame_b).
F32 interleaved and F32p planar audio are blended; all other formats
fall back to returning frame_a unchanged. When sample formats differ,
frame_a is returned unchanged.