pub enum TrackType {
Video,
Audio,
Subtitle,
}Expand description
Type of track.
Variants
Implementations
Sourceimpl TrackType
impl TrackType
Sourcepub fn matches_clip(&self, clip_type: ClipType) -> bool
pub fn matches_clip(&self, clip_type: ClipType) -> bool
Check if this track type matches a clip type.
Sourcepub fn expected_clip_type(&self) -> ClipType
pub fn expected_clip_type(&self) -> ClipType
Return the clip type that this track type accepts.