pub enum IssueKind {
OverlappingClips {
track_index: usize,
clip_a: u64,
clip_b: u64,
},
Gap {
track_index: usize,
gap_start: i64,
gap_end: i64,
},
ZeroDurationClip {
track_index: usize,
clip_id: u64,
},
InvalidSourceRange {
track_index: usize,
clip_id: u64,
source_in: i64,
source_out: i64,
},
NegativeTimelineStart {
track_index: usize,
clip_id: u64,
start: i64,
},
InvalidSpeed {
track_index: usize,
clip_id: u64,
speed: f64,
},
DuplicateClipId {
clip_id: u64,
},
OpacityOutOfRange {
track_index: usize,
clip_id: u64,
opacity: f32,
},
EmptyTrack {
track_index: usize,
},
DurationMismatch {
reported: i64,
actual: i64,
},
}Expand description
Specific type of validation finding.
Variants
OverlappingClips
Two clips on the same track overlap in time.
Gap
A gap exists between consecutive clips on a track.
Fields
ZeroDurationClip
A clip has zero or negative duration.
InvalidSourceRange
A clip’s source_in >= source_out.
Fields
NegativeTimelineStart
A clip has a negative timeline start.
Fields
InvalidSpeed
Clip speed is zero or negative.
Fields
DuplicateClipId
Duplicate clip ID found across the timeline.
OpacityOutOfRange
A clip’s opacity is outside [0.0, 1.0].
Fields
EmptyTrack
An empty track (no clips).
DurationMismatch
Timeline reported duration does not match actual clip extents.