pub struct OverlayManager { /* private fields */ }Expand description
Manages a collection of title overlays for a project.
Implementations
Sourceimpl OverlayManager
impl OverlayManager
Sourcepub fn add(&mut self, overlay: TitleOverlay) -> OverlayId
pub fn add(&mut self, overlay: TitleOverlay) -> OverlayId
Add an overlay and return its assigned ID.
Sourcepub fn remove(&mut self, id: OverlayId) -> Option<TitleOverlay>
pub fn remove(&mut self, id: OverlayId) -> Option<TitleOverlay>
Remove an overlay by ID.
Sourcepub fn get(&self, id: OverlayId) -> Option<&TitleOverlay>
pub fn get(&self, id: OverlayId) -> Option<&TitleOverlay>
Get a reference to an overlay.
Sourcepub fn get_mut(&mut self, id: OverlayId) -> Option<&mut TitleOverlay>
pub fn get_mut(&mut self, id: OverlayId) -> Option<&mut TitleOverlay>
Get a mutable reference.
Sourcepub fn active_at(&self, time: i64) -> Vec<&TitleOverlay>
pub fn active_at(&self, time: i64) -> Vec<&TitleOverlay>
Return all overlays active at time, sorted by ID for deterministic order.